@@ -1,4 +1,6 @@
-#include <Python.h>
+#define Py_LIMITED_API 0x03060000
+#define PY_SSIZE_T_CLEAN
+#include "Python.h"
 #include "pyobjc-api.h"
 
 #import <CoreServices/CoreServices.h>
@@ -23,40 +25,30 @@ mod_release(const void* info)
     PyGILState_Release(state);
 }
 
-
 static CFStreamClientContext mod_CFStreamClientContext = {
-    0,
-    NULL,
-    (void*(*)(void*))mod_retain,
-    (void(*)(void*))mod_release,
-    NULL
-};
+    0, NULL, (void* (*)(void*))mod_retain, (void (*)(void*))mod_release, NULL};
 
-static CFHostClientContext mod_CFHostClientContext = {
-    0,
-    NULL,
-    mod_retain,
-    mod_release,
-    0
-};
+static CFHostClientContext mod_CFHostClientContext = {0, NULL, mod_retain, mod_release,
+                                                      0};
 
 #if PyObjC_BUILD_RELEASE >= 1005
 static void
-m_CFProxyAutoConfigurationResultCallback(void* _context, CFArrayRef proxyList, CFErrorRef error)
+m_CFProxyAutoConfigurationResultCallback(void* _context, CFArrayRef proxyList,
+                                         CFErrorRef error)
 {
     PyObject* context = (PyObject*)_context;
 
     PyGILState_STATE state = PyGILState_Ensure();
 
-    PyObject* py_func = PyTuple_GET_ITEM(context, 0);
-    PyObject* py_ctx = PyTuple_GET_ITEM(context, 1);
+    PyObject* py_func = PyTuple_GetItem(context, 0);
+    PyObject* py_ctx  = PyTuple_GetItem(context, 1);
 
-    PyObject* py_list = PyObjC_IdToPython((NSObject*)proxyList);
+    PyObject* py_list = PyObjC_IdToPython((NSObject*)(NSArray*)proxyList);
     if (py_list == NULL) {
         PyObjCErr_ToObjCWithGILState(&state);
         return;
     }
-    PyObject* py_error = PyObjC_IdToPython((NSObject*)error);
+    PyObject* py_error = PyObjC_IdToPython((NSObject*)(NSError*)error);
     if (py_error == NULL) {
         Py_DECREF(py_list);
         PyObjCErr_ToObjCWithGILState(&state);
@@ -76,14 +68,15 @@ m_CFProxyAutoConfigurationResultCallback(void* _context, CFArrayRef proxyList, C
 #endif
 
 static void
-m_CFHostClientCallBack(CFHostRef host, CFHostInfoType typeInfo, const CFStreamError* error, void* _context)
+m_CFHostClientCallBack(CFHostRef host, CFHostInfoType typeInfo,
+                       const CFStreamError* error, void* _context)
 {
     PyObject* context = (PyObject*)_context;
 
     PyGILState_STATE state = PyGILState_Ensure();
 
-    PyObject* py_func = PyTuple_GET_ITEM(context, 0);
-    PyObject* py_ctx = PyTuple_GET_ITEM(context, 1);
+    PyObject* py_func = PyTuple_GetItem(context, 0);
+    PyObject* py_ctx  = PyTuple_GetItem(context, 1);
 
     PyObject* py_host = PyObjC_IdToPython((NSObject*)host);
     if (py_host == NULL) {
@@ -97,11 +90,7 @@ m_CFHostClientCallBack(CFHostRef host, CFHostInfoType typeInfo, const CFStreamEr
         return;
     }
 
-#ifdef __LP64__
     PyObject* py_error = PyObjC_ObjCToPython("{_CFStreamError=qi}", (void*)error);
-#else
-    PyObject* py_error = PyObjC_ObjCToPython("{_CFStreamError=ll}", (void*)error);
-#endif
     if (py_error == NULL) {
         Py_DECREF(py_host);
         Py_DECREF(py_info);
@@ -109,7 +98,8 @@ m_CFHostClientCallBack(CFHostRef host, CFHostInfoType typeInfo, const CFStreamEr
         return;
     }
 
-    PyObject* rv = PyObject_CallFunction(py_func, "NNNO", py_host, py_info, py_error, py_ctx);
+    PyObject* rv =
+        PyObject_CallFunction(py_func, "NNNO", py_host, py_info, py_error, py_ctx);
 
     if (rv == NULL) {
         PyObjCErr_ToObjCWithGILState(&state);
@@ -120,21 +110,16 @@ m_CFHostClientCallBack(CFHostRef host, CFHostInfoType typeInfo, const CFStreamEr
     PyGILState_Release(state);
 }
 
-
-#if PyObjC_BUILD_RELEASE >= 1005
-  /* This function is available on 10.5 or later, but the prototype isn't in the headers on 10.5 */
-WEAK_LINKED_NAME_10_5(CFNetworkExecuteProxyAutoConfigurationScript)
-
 static PyObject*
 m_CFNetworkExecuteProxyAutoConfigurationScript(PyObject* mod __attribute__((__unused__)),
-            PyObject* args)
+                                               PyObject* args)
 {
     CFStringRef script;
-    CFURLRef url;
-    PyObject* callback;
-    PyObject* ctx;
-    PyObject* py_script;
-    PyObject* py_url;
+    CFURLRef    url;
+    PyObject*   callback;
+    PyObject*   ctx;
+    PyObject*   py_script;
+    PyObject*   py_url;
 
     if (!PyArg_ParseTuple(args, "OOOO", &py_script, &py_url, &callback, &ctx)) {
         return NULL;
@@ -156,20 +141,19 @@ m_CFNetworkExecuteProxyAutoConfigurationScript(PyObject* mod __attribute__((__un
     }
 
     CFStreamClientContext context = mod_CFStreamClientContext;
-    context.info = py_context;
+    context.info                  = py_context;
 
     CFRunLoopSourceRef ref = NULL;
 
-    PyObjC_DURING
-        ref = USE_10_5(CFNetworkExecuteProxyAutoConfigurationScript)(
-                       script, url,
-                       m_CFProxyAutoConfigurationResultCallback,
-                       &context);
-    PyObjC_HANDLER
-        PyObjCErr_FromObjC(localException);
-        ref = NULL;
-
-    PyObjC_ENDHANDLER
+    Py_BEGIN_ALLOW_THREADS
+        @try {
+            ref = CFNetworkExecuteProxyAutoConfigurationScript(
+                script, url, m_CFProxyAutoConfigurationResultCallback, &context);
+        } @catch (NSException* localException) {
+            PyObjCErr_FromObjC(localException);
+            ref = NULL;
+        }
+    Py_END_ALLOW_THREADS
 
     Py_DECREF(py_context);
 
@@ -181,17 +165,13 @@ m_CFNetworkExecuteProxyAutoConfigurationScript(PyObject* mod __attribute__((__un
 
     return rv;
 }
-#endif
-
-#if PyObjC_BUILD_RELEASE >= 1005
-WEAK_LINKED_NAME_10_5(CFNetworkExecuteProxyAutoConfigurationURL)
 
 static PyObject*
 m_CFNetworkExecuteProxyAutoConfigurationURL(PyObject* mod __attribute__((__unused__)),
-        PyObject* args)
+                                            PyObject* args)
 {
-    CFURLRef script;
-    CFURLRef url;
+    CFURLRef  script;
+    CFURLRef  url;
     PyObject* callback;
     PyObject* ctx;
     PyObject* py_script;
@@ -217,20 +197,19 @@ m_CFNetworkExecuteProxyAutoConfigurationURL(PyObject* mod __attribute__((__unuse
     }
 
     CFStreamClientContext context = mod_CFStreamClientContext;
-    context.info = py_context;
+    context.info                  = py_context;
 
     CFRunLoopSourceRef ref = NULL;
 
-    PyObjC_DURING
-        ref = USE_10_5(CFNetworkExecuteProxyAutoConfigurationURL)(
-            script, url,
-            m_CFProxyAutoConfigurationResultCallback,
-            &context);
-    PyObjC_HANDLER
-        PyObjCErr_FromObjC(localException);
+    Py_BEGIN_ALLOW_THREADS
+        @try {
+            ref = CFNetworkExecuteProxyAutoConfigurationURL(
+                script, url, m_CFProxyAutoConfigurationResultCallback, &context);
+        } @catch (NSException* localException) {
+            PyObjCErr_FromObjC(localException);
             ref = NULL;
-
-    PyObjC_ENDHANDLER
+        }
+    Py_END_ALLOW_THREADS
 
     Py_DECREF(py_context);
 
@@ -242,7 +221,6 @@ m_CFNetworkExecuteProxyAutoConfigurationURL(PyObject* mod __attribute__((__unuse
 
     return rv;
 }
-#endif /* OSX 10.5 */
 
 static PyObject*
 m_CFHostSetClient(PyObject* mod __attribute__((__unused__)), PyObject* args)
@@ -251,7 +229,7 @@ m_CFHostSetClient(PyObject* mod __attribute__((__unused__)), PyObject* args)
     PyObject* callback;
     PyObject* ctx;
     PyObject* py_host;
-    Boolean ok = 0;
+    Boolean   ok = 0;
 
     if (!PyArg_ParseTuple(args, "OOO", &py_host, &callback, &ctx)) {
         return NULL;
@@ -263,12 +241,13 @@ m_CFHostSetClient(PyObject* mod __attribute__((__unused__)), PyObject* args)
     }
 
     if (callback == Py_None) {
-        PyObjC_DURING
-            ok = CFHostSetClient(host, NULL, NULL);
-        PyObjC_HANDLER
-            PyObjCErr_FromObjC(localException);
-
-        PyObjC_ENDHANDLER
+        Py_BEGIN_ALLOW_THREADS
+            @try {
+                ok = CFHostSetClient(host, NULL, NULL);
+            } @catch (NSException* localException) {
+                PyObjCErr_FromObjC(localException);
+            }
+        Py_END_ALLOW_THREADS
 
         if (PyErr_Occurred()) {
             return NULL;
@@ -283,18 +262,15 @@ m_CFHostSetClient(PyObject* mod __attribute__((__unused__)), PyObject* args)
     }
 
     CFHostClientContext context = mod_CFHostClientContext;
-    context.info = py_context;
+    context.info                = py_context;
 
-
-    PyObjC_DURING
-        ok = CFHostSetClient(
-            host,
-            m_CFHostClientCallBack,
-            &context);
-    PyObjC_HANDLER
-        PyObjCErr_FromObjC(localException);
-
-    PyObjC_ENDHANDLER
+    Py_BEGIN_ALLOW_THREADS
+        @try {
+            ok = CFHostSetClient(host, m_CFHostClientCallBack, &context);
+        } @catch (NSException* localException) {
+            PyObjCErr_FromObjC(localException);
+        }
+    Py_END_ALLOW_THREADS
 
     Py_DECREF(py_context);
 
@@ -305,51 +281,44 @@ m_CFHostSetClient(PyObject* mod __attribute__((__unused__)), PyObject* args)
     return PyBool_FromLong(!!ok);
 }
 
-
-
 static PyMethodDef mod_methods[] = {
 #if PyObjC_BUILD_RELEASE >= 1005
-    {
-        "CFNetworkExecuteProxyAutoConfigurationScript",
-        (PyCFunction)m_CFNetworkExecuteProxyAutoConfigurationScript,
-        METH_VARARGS,
-        "CFNetworkExecuteProxyAutoConfigurationScript(arg0, arg1, arg2, arg3)"
-    },
+    {"CFNetworkExecuteProxyAutoConfigurationScript",
+     (PyCFunction)m_CFNetworkExecuteProxyAutoConfigurationScript, METH_VARARGS,
+     "CFNetworkExecuteProxyAutoConfigurationScript(arg0, arg1, arg2, arg3)"},
 #endif /* OSX >= 10.5 */
 #if PyObjC_BUILD_RELEASE >= 1005
-    {
-        "CFNetworkExecuteProxyAutoConfigurationURL",
-        (PyCFunction)m_CFNetworkExecuteProxyAutoConfigurationURL,
-        METH_VARARGS,
-        "CFNetworkExecuteProxyAutoConfigurationURL(arg0, arg1, arg2, arg3)"
-    },
+    {"CFNetworkExecuteProxyAutoConfigurationURL",
+     (PyCFunction)m_CFNetworkExecuteProxyAutoConfigurationURL, METH_VARARGS,
+     "CFNetworkExecuteProxyAutoConfigurationURL(arg0, arg1, arg2, arg3)"},
 #endif /* OSX >= 10.5 */
 
+    {"CFHostSetClient", (PyCFunction)m_CFHostSetClient, METH_VARARGS,
+     "CFHostSetClient(arg0, arg1, arg2)"},
+
     {
-        "CFHostSetClient",
-        (PyCFunction)m_CFHostSetClient,
-        METH_VARARGS,
-        "CFHostSetClient(arg0, arg1, arg2)"
-    },
+        0,
+        0,
+        0,
+    }};
 
-    { 0, 0, 0, }
-};
+static struct PyModuleDef mod_module = {
+    PyModuleDef_HEAD_INIT, "_manual", NULL, 0, mod_methods, NULL, NULL, NULL, NULL};
 
-PyObjC_MODULE_INIT(_manual)
+PyObject* PyInit__manual(void);
+
+PyObject* __attribute__((__visibility__("default"))) PyInit__manual(void)
 {
     PyObject* m;
 
-    m = PyObjC_MODULE_CREATE(_manual)
+    m = PyModule_Create(&mod_module);
     if (!m) {
-        PyObjC_INITERROR();
+        return NULL;
     }
 
     if (PyObjC_ImportAPI(m) < 0) {
-        PyObjC_INITERROR();
+        return NULL;
     }
 
-    CHECK_WEAK_LINK_10_5(m, CFNetworkExecuteProxyAutoConfigurationScript);
-    CHECK_WEAK_LINK_10_5(m, CFNetworkExecuteProxyAutoConfigurationURL);
-
-    PyObjC_INITDONE();
+    return m;
 }
